import React, { useEffect, useState, useRef } from "react";
import { useNavigate } from "react-router-dom";
import ContentEditable from "react-contenteditable";

//components
import Icon from "~/components/Icon";
import Loading from "~/components/Loading";
import appConfig from "~/config";
const { redirects } = appConfig;
const downloadUrl = (file_path) => {
  var a = window.document.createElement("A");
  a.href = file_path;
  a.target = "_blank";
  a.download = file_path.substr(file_path.lastIndexOf("/") + 1);
  window.document.body.appendChild(a);
  a.click();
  window.document.body.removeChild(a);
};
const Button = ({
  id,
  badge,
  tabIndex,
  draggable,
  onDragStart,
  style,
  text,
  link,
  icon,
  iconColor,
  iconSize,
  iconSet,
  iconClassName,
  disabled,
  scale,
  surface,
  title,
  primary,
  outline,
  action,
  loading: loading_,
  className,
  children,

  textClassName,
  progress,
  dropdown,
  hoverDropdown,
  refAction = () => {},
  ref,
  editable,
  onChange,
  inputRef,
  target,
  badgeCalssName,
  dropdownClassName,
  dpClassName,
}) => {
  const dropdownRef = useRef();
  if (editable) {
    link = undefined;
    action = undefined;
  }
  if (ref && !refAction) refAction = ref;
  const navigate = useNavigate();
  const [menu, setMenu] = useState(false);
  const [loading, setLoading] = useState(loading_);
  const outsideClick = (event) => {
    if (dropdownRef.current && !dropdownRef.current.contains(event.target)) {
      event.preventDefault();
      setMenu(false);
    }
  };
  useEffect(() => {
    if (menu) document.addEventListener("mousedown", outsideClick);
    else document.removeEventListener("mousedown", outsideClick);
  }, [menu]);
  useEffect(() => {
    setLoading(loading_);
  }, [loading_]);

  className = className || "";
  if (outline)
    className += " border  border-primary text-primary  hover:bg-surface";
  if (primary) {
    if (!className.includes("bg-"))
      className += " font-6 bg-primary hover:brightness-90";
    className += ` text-primaryText  `;
    // primaryColor = "text-primaryText";
  }

  if (surface) className += ` bg-surface text-surfaceText `;
  if (disabled) className += ` grayscale opacity-80`;
  if (scale) className += ` hover:scale-105`;
  if (!className.includes("justify")) className += ` justify-center`;
  if (!className.includes("rounded")) className += ` rounded-md`;
  const doAction = async (e) => {
    setLoading(true);
    if (!menu && action) await action(e);
    if (dropdown) setMenu(true);
    setLoading(false);
  };
  let timer;
  let Container = !dropdown ? React.Fragment : DropdownContainer;
  return (
    <Container>
      <button
        id={id || null}
        tabIndex={tabIndex}
        draggable={draggable}
        onDragStart={onDragStart}
        style={style || {}}
        ref={inputRef}
        title={title || text}
        className={`${className} flex text-sm my-2 py-2 gap-2   transition-all    items-center `}
        onMouseEnter={
          hoverDropdown
            ? () =>
                (timer = setTimeout(() => {
                  setMenu(true);
                }, 100))
            : null
        }
        onMouseLeave={
          hoverDropdown
            ? () =>
                (timer = setTimeout(() => {
                  setMenu(false);
                }, 100))
            : null
        }
        onClick={(e) => {
          e.preventDefault();
          e.stopPropagation();
          if (!disabled && !loading) {
            if (dropdown || action) doAction(e);
            if (redirects[link]) link = redirects[link];
            if (typeof link == "string")
              if (target == "download") downloadUrl(link);
              else if (link.includes("http") && target == "_self")
                window.location.href = link;
              else if (link.includes("http") || link.slice(0, 4) == "data") {
                let w = window.open(link, target || "_blank", true);
                if (link.slice(0, 4) == "data") {
                  let image = new Image();
                  image.src = link;
                  setTimeout(function () {
                    w.document.write(image.outerHTML);
                  }, 0);
                }
              } else if (link.includes("#"))
                window.document.querySelector(link).scrollIntoView({
                  behavior: "smooth",
                  block: "start",
                  inline: "nearest",
                });
              else {
                if (window.event.ctrlKey || (target && target != "_self"))
                  window.open(
                    !appConfig.base ? link : "/" + appConfig.base + link,
                    target || "_blank"
                  );
                else
                  navigate(
                    !appConfig.base ? link : "/" + appConfig.base + link
                  );
              }
            else if (link) navigate(link);
          }
        }}
      >
        {loading && progress > 0 && (
          <div className={`${textClassName}`}>{progress}%</div>
        )}
        {loading ? (
          <Loading
            text=""
            textClassName={"text-[white]"}
            color={primary ? "white" : ""}
            size={10}
          />
        ) : null}
        {icon && (
          <Icon
            name={icon}
            color={
              iconColor || (primary && "var(--primaryText)") || "var(--primary)"
            }
            size={iconSize}
            variant={iconSet}
            className={
              (editable ? "" : text ? "" : "flex-1 ") + (iconClassName || "")
            }
          />
        )}

        {editable ? (
          <ContentEditable
            html={text}
            onChange={(e) => onChange(e.target.value)}
            className={!text ? " w-1 rounded " : "min-w-10 "}
          />
        ) : (
          text &&
          text != " " && <div className={`${textClassName}`}>{text}</div>
        )}
        {badge ? (
          <div className="relative ltr -left-1">
            <span
              className={
                badgeCalssName +
                ` bg-error text-primaryText text-[12px] px-2 absolute rtl bottom-2 rounded-lg`
              }
            >
              {badge}
            </span>
          </div>
        ) : null}
        {!dropdown ? children : null}
      </button>
      {dropdown ? (
        <div
          ref={dropdownRef}
          className={
            dpClassName + " absolute ltr:left-0 rtl:right-0 translate-x-0  "
          }
        >
          <div
            id="dropdown"
            className={`${
              menu ? "" : "hidden"
            } min-w-fit px-2 absolute text-xs list-none  rounded-lg divide-gray-100 shadow-xl bg-background  my-0 py-0   ${dropdownClassName}`}
            onMouseLeave={() => setMenu(false)}
            onMouseEnter={() => clearTimeout(timer)}
          >
            {children}
          </div>
        </div>
      ) : null}
    </Container>
  );
};

const DropdownContainer = ({ children }) => {
  return <div className="">{children}</div>;
};

export default Button;
