import React,{useState} from "react";
//components
import Button from "~/components/Button";
import Icon from "~/components/Icon";
import BottomSheet from "~/components/BottomSheet";

export const Dialog = ({ dialog, setDialog }) => {
  
  const [boxAnimation, setBoxAnimation] = useState(false);
  if (!dialog.open) return null;
  let {
    text,
    type = "confirm",
    accept,
    children,
    className,
    action,
    cancel,
    loading,
    progress,
    footer,
    icon,
    iconColor,
  } = dialog;
  accept = accept || action;
  React.useEffect(() => {
    setTimeout(() => {
      setBoxAnimation(true);
    }, 200);

    return () => {
      setBoxAnimation(false);
    };
  }, []);

  const exit = React.useCallback(
    (e) => {
      cancel && cancel();
      setDialog({ ...dialog, open: !dialog.open });
      e.stopPropagation();
    },
    [dialog, setDialog]
  );

  const acceptFunc = React.useCallback(() => {
    accept();
    setDialog({ ...dialog, open: !dialog.open });
    // e.stopPropagation();
  }, [dialog, setDialog, accept]);

  return (
    <>
      <div
        className=" hidden md:flex w-screen h-full fixed top-0 right-0 bg-surfaceDark bg-opacity-10 backdrop-filter backdrop-blur-lg  justify-center items-center"
        style={{ zIndex: 70 }}
        onClick={(e) => exit(e)}
      >
        <div
          className={`flex flex-col items-center bg-surfaceLight bg-opacity-100 text-surfaceText md:min-w-[500px] p-3 gap-2   rounded-md transition-all transform shadow ${
            boxAnimation ? "scale-100" : "scale-0"
          }`}
          style={{ minWidth: 300 }}
          onClick={(e) => e.stopPropagation()}
        >
          <div
            className={`${className} text-tiny p-${
              text ? 4 : 2
            } text-gray-22 bg-surface rounded-md  w-full leading-7`}
          >
            <div className="flex items-center w-full gap-2 justify-center">
              {icon && <Icon name={icon} size={32} />} <span>{text}</span>
            </div>
            {children}
          </div>
          <div className="modal-footer  w-full  flex md:flex-row flex-col gap-1 justify-between  ">
            {footer && <div className="flex-1">{footer}</div>}
            {type === "confirm" && (
              <div className="flex  gap-4 w-full">
                <Button
                  text="تایید"
                  primary
                  action={acceptFunc}
                  className="flex-1 !my-0"
                  loading={loading}
                  progress={progress}
                />
                <Button
                  text="انصراف"
                  outline
                  className="flex-1 !my-0"
                  action={exit}
                />
              </div>
            )}
            {type === "alert" && (
              <div className="flex  gap-4 w-full">
                <Button
                  text="تایید"
                  loading={loading}
                  progress={progress}
                  primary
                  className="flex-1 !my-0"
                  action={acceptFunc}
                />
              </div>
            )}
          </div>
        </div>
      </div>
      <BottomSheet
        className={"md:hidden block h-fit"}
        cancel={exit}
        hidden={!dialog.open}
        height={text ? 300 : (window.innerHeight * 2) / 3}
      >
        <div className="p-2 rtl">
          <div className="flex items-center w-full gap-2 justify-center">
            {icon && <Icon name={icon} size={32} color={iconColor} />}{" "}
            <span>{text}</span>
          </div>
          {children}
        </div>
        <div className="flex gap-2 bg-opacity-100 ">
          <div className="modal-footer absolute left-0 bottom-2 px-2 pt-2 gap-1 rtl w-full flex  justify-between px-2  flex-col  bg-background  ">
            {footer && <div>{footer}</div>}
            <div className="modal-footer  w-full  flex md:flex-row flex-col gap-1 justify-between  ">
              {footer && <div className="flex-1">{footer}</div>}
              {type === "confirm" && (
                <div className="flex  gap-4 w-full">
                  <Button
                    text="تایید"
                    primary
                    action={acceptFunc}
                    className="flex-1 !my-0"
                    loading={loading}
                    progress={progress}
                  />
                  <Button
                    text="انصراف"
                    outline
                    className="flex-1 !my-0"
                    action={exit}
                  />
                </div>
              )}
              {type === "alert" && (
                <div className="flex  gap-4 w-full">
                  <Button
                    text="تایید"
                    loading={loading}
                    progress={progress}
                    primary
                    className="flex-1 !my-0"
                    action={acceptFunc}
                  />
                </div>
              )}
            </div>
          </div>
        </div>
      </BottomSheet>
    </>
  );
};

export default Dialog;
