import proxy from "~/redux/proxy";
const extToMimes = {
  jpg: "image/jpeg",
  png: "image/png",
  mp4: "video/mp4",
  doc: "application/msword",
  bmp: "image/bmp",
  docx: "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
  xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
  mp3: "audio/mpeg",
  pdf: "application/pdf",
  zip: "application/zip",
  rar: "application/vnd.rar",
};
const headers = {
  "504B0304": "application/zip",
  25504446: "application/pdf",
  "504b34":
    "application/x-zip-compressed|application/vnd.openxmlformats-officedocument.wordprocessingml.document|application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
  "89504e47": "image/png",
  ffd8ffe0: "image/jpeg",
  ffd8ffe1: "image/jpeg",
  ffd8ffe2: "image/jpeg",
  ffd8ffe3: "image/jpeg",
  ffd8ffe8: "image/jpeg",
  47494638: "image/gif",
  d0cf11e0: "application/msword",
  "6674797069736F6D": "video/mp4",
  494433: "audio/mpeg",
  "526172211A0700": "application/vnd.rar",
  "526172211A070100": "application/vnd.rar",
  "424D": "image/bmp",
  "223f636f": "text/csv",
};
function getMimeType(file, callback) {
  const fileReader = new FileReader();
  fileReader.onloadend = function (event) {
    let mimeType = "";

    const arr = new Uint8Array(event.target.result).subarray(0, 4);
    let header = "";

    for (let index = 0; index < arr.length; index++) {
      header += arr[index].toString(16);
    }
    mimeType = headers[header];
    if (!mimeType) console.log("!mimeType Header:", header);
    callback(mimeType);
  };

  fileReader.readAsArrayBuffer(file);
}
// import * as fileType from "file-type";
const file = {
  getLimits:
    (data = {}) =>
    async (dispatch) =>
      await proxy.get("file/limits", data, { dispatch }),
  setSignature:
    (data = {}) =>
    async (dispatch) =>
      await dispatch({ type: "file/setSignature", data }),
  upload:
    (data = {}) =>
    async (dispatch) => {
      let mimeType = await new Promise((r) => getMimeType(data.file, r));
      if (
        !window.config.admin_config_uploadExtensions
          .split(",")
          .includes(data.file.name.split(".").slice(-1)[0])
      )
        return { statusCode: 400, message: "پسوند فایل ارسالی مجاز نیست" };

      if (!mimeType || !mimeType.split("|").includes(data.file.type))
        return { statusCode: 400, message: "فرمت فایل ارسالی مجاز نیست" };
      if (
        data.file.size >
        window.config.admin_config_maxUploadSize * 1024 * 1024
      )
        return {
          statusCode: 400,
          message: `حجم فایل ارسالی باید کمتر از ${window.config.admin_config_maxUploadSize} مگابایت باشد`,
        };
      var formData = new FormData();
      for (let key in data) formData.append(key, data[key]);
      return await proxy.post(
        "file/upload",
        formData,
        {
          dispatch,
          headers: {
            "Content-Type": "multipart/form-data",
          },
        },
        data
      );
    },
  directUpload:
    (data = {}) =>
    async (dispatch) => {
      var formData = new FormData();
      for (let key in data) formData.append(key, data[key]);
      return await proxy.post(
        "file/directUpload",
        formData,
        {
          dispatch,
          headers: {
            "Content-Type": "multipart/form-data",
          },
        },
        data
      );
    },
  loading: (data) => (dispatch) => dispatch({ type: "file/loading", data }),
  groupList:
    (data = {}) =>
    async (dispatch) =>
      await proxy.get("file/group/list", data, { dispatch }),
};

export default file;
