import _ from "lodash";
import axios from "axios";
import config from "~/config";
import bcrypt from "bcryptjs";
let { baseUrl, TTL = 360 } = config;
if (window.location.href.includes("barnamenegar.com"))
  baseUrl = "https://sameh.barnamenegar.com/api/v2/";
let Axios;
let progressDespatch;
const race = (promises) =>
  new Promise((resolve, reject) => {
    for (const promise of promises) promise.then(resolve, reject);
  });

export const reAxios = async (baseUrl) => {
  if (window.location.href.includes("barnamenegar.com"))
    baseUrl = "https://sameh.barnamenegar.com/api/v2/";
  let access;
  let sessionId = sessionStorage.getItem("sessionId");
  if (sessionId) access = btoa(bcrypt.hashSync(sessionId, 10));
  baseUrl = baseUrl || config.baseUrl;
  Axios = axios.create({
    onUploadProgress: (progressEvent) => {
      if (progressDespatch) {
        progressDespatch(
          Math.round((progressEvent.loaded / progressEvent.total) * 100)
        );
      }
    },
    withCredentials: true,
    validateStatus: null,
    baseURL: baseUrl,
    headers: access ? { Authorization: `Bearer ${access}` } : {},
  });
  window.Axios = Axios;
};
reAxios();
window.reAxios = reAxios;
class Proxy {
  get = async (url, params, opt, data) =>
    await this.check(
      url,
      opt,
      async () => await Axios.get(url, { params, _service: undefined, ...opt }),
      data || params
    );
  post = async (url, params, opt, data) =>
    await this.check(
      url,
      opt,
      async () => await Axios.post(url, params, opt),
      data || params
    );
  put = async (url, params, opt, data) => {
    if (window.location.href.includes("barnamenegar.com"))
      return await this.post(url, params, opt, data);
    return await this.check(
      url,
      opt,
      async () => await Axios.put(url, params, opt),
      data || params
    );
  };
  delete = async (url, params, opt, data) => {
    if (window.location.href.includes("barnamenegar.com"))
      return await this.post(url, params, opt, data);
    return await this.check(
      url,
      opt,
      async () => await Axios.delete(url, { ...opt, data: params }),
      data || params
    );
  };
  timeout = new Promise((r) =>
    setTimeout(
      () => r({ data: { status: 500, message: "سرور پاسخگو نیست" } }),
      TTL * 1000
    )
  );

  check = async (url, { dispatch }, fetch, params) => {
    dispatch = dispatch || (() => {});
    url && dispatch({ type: url.split("/")[0] + "/loading", params });
    progressDespatch = (p) => {
      dispatch({ type: url.split("/")[0] + "/progress", data: p });
    };
    const response = await race([
      new Promise(async (r) => r(await fetch())),
      new Promise(async (r) =>
        setTimeout(
          () => r({ status: 500, message: "خطا: عدم پاسخگویی اتصال به سرور" }),
          TTL * 1000
        )
      ),
    ]);
    switch (response.status) {
      case 200:
        window.serverDate = response.data.date;
        (response.data?.logs || []).forEach((r) => {
          if (r[0].etag)
            console[r[0].mode](
              `${config.baseUrl}/${url} ${r[0].name}:${r[0].line}:${r[0].time}ms`,
              ...r.slice(1)
            );
        });
        dispatch({
          type: url,
          data: response.data.data,
          schema: response.data.schema,
          count: response.data.count,
          message: response.data.message,
          params,
          headers: response.headers,
        });

        return response.data.data;
      case 401:
        let refresh = false; // await this.refresh();
        if (refresh) {
          let response = await fetch();
          dispatch({ type: url, data: response.data.data });
          return response.data.data;
        } else {
          sessionStorage.removeItem("userData");
          sessionStorage.removeItem("sessionId");
          window.location.href = "/login";
        }
        // dispatch({
        //   type: url.split("/")[0] + "/error",
        //   data: response.data || response,
        // });
        break;
      case 403:
      default:
        dispatch({
          type: url.split("/")[0] + "/error",
          data: response?.data?.data ||
            response?.data || { message: "خطای برقراری ارتباط" },
          message:
            response.data?.message == undefined
              ? "خطای برقراری ارتباط"
              : response.data?.message,
          params,
        });
        return { statusCode: response.status, message: response.data?.message };
    }
    return false;
  };

  login = async (url, params, opt = {}) => {
    let { dispatch } = opt;
    this.post(url, params, {
      dispatch: async (obj) => {
        console.log({ obj });
        let login = obj.data;
        let sessionId = obj.headers?.sessionid;
        if (!login) return dispatch(obj);
        console.log({ obj });
        sessionStorage.removeItem("userData");
        sessionStorage.removeItem("sessionId");
        await new Promise((r) => setTimeout(r, 100));
        delete login.accessToken;
        delete login.refreshToken;
        if (!login.statusCode) {
          sessionStorage.setItem("userData", JSON.stringify(login));
          sessionStorage.setItem("sessionId", sessionId);
        }
        if (!localStorage.getItem("activeRoleId"))
          localStorage.setItem("activeRoleId", 0);
        // clearInterval(window.checkValidation);
        // window.checkValidation = setInterval(() => {
        //   console.log("start validation");
        //   try {
        //     let validation = JSON.parse(
        //       sessionStorage.getItem("userData")
        //     ).validation;
        //     console.log({ validation, now: new Date().getTime() });

        //     if (!validation || validation < new Date().getTime())
        //       throw new Error("not validated");
        //   } catch (e) {
        //     console.log(e.message, e);
        //     localStorage.removeItem("activeRoleId");
        //     window.sessionStorage.clear();
        //     return window.location.reload();
        //   }
        // }, 300 * 1000);
        reAxios();
        dispatch(obj);
      },
    });
  };

  logout = async (url, params, { dispatch }) => {
    clearInterval(window.checkValidation);
    dispatch({ type: url.split("/")[0] + "/loading" });
    await this.post(url, params, {
      dispatch: (obj) => {
        localStorage.removeItem("activeRoleId");
        window.navigator.serviceWorker
          .getRegistrations()
          .then(function (registrations) {
            for (let registration of registrations) {
              registration.unregister();
            }
          });

        dispatch(obj);
      },
    });
  };
  status = () => {
    const userData = sessionStorage.getItem("userData");
    if (userData) {
      // clearInterval(window.checkValidation);
      // window.checkValidation = setInterval(() => {
      //   try {
      //     let validation = JSON.parse(
      //       sessionStorage.getItem("userData")
      //     ).validation;
      //     console.log({ validation, now: new Date().getTime() });
      //     if (!validation || validation < new Date().getTime())
      //       throw new Error("not validated");
      //   } catch (e) {
      //     console.log(e.message, e);
      //     localStorage.removeItem("activeRoleId");
      //     window.sessionStorage.clear();
      //     return window.location.reload();
      //   }
      // }, 300 * 1000);
    }
    return userData ? JSON.parse(userData) : null;
    // let profile = await axios.get("user/fetProfile");
    // sessionStorage.setItem("userData", JSON.stringify(profile.data));
    // console.log(profile);
    // return profile.data;
  };
}
const _proxy = new Proxy();

export default _proxy;
