import config from "~/config";
import { toast } from "react-toastify";

let { baseUrl } = config;
if (window.location.href.includes("barnamenegar.com"))
  baseUrl = "https://sameh.barnamenegar.com/api/v2/";
const initialState = {
  userFactor: {
    beforeSchema: [
      {
        text: "نمایش",
        description: "نمایش",
        type: "button",
        link: "`factor?id=${row.id}`",
      },
    ],
  },
  file: {
    beforeSchema: [
      {
        text: "نمایش",
        description: "نمایش",
        link:
          "`${row.type=='folder'? 'file/?pid='+row.id: '" +
          baseUrl +
          "file/'+row.id}`",
        type: "button",
      },
    ],
  },
  info: {},
};

export default function auto(state = initialState, action) {
  let { type, data, schema, count, params, message } = action;
  if (!params && !params?._service) return state;
  const pathPrefix = `auto/${params._service}/`;
  if (type == "auto/loading")
    return {
      ...state,
      loading: true,
    };
  if (type == "auto/error") {
    toast.error(message, { autoClose: !message.includes("!!") });
    return {
      ...state,
      loading: false,
    };
  }
  switch (type.split(pathPrefix)[1]) {
    case "":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          [params._service]: {
            ...state[params._service],
            loading: false,
            error: null,

            excelData: data,
          },
        };
      if (params._append)
        return {
          ...state,
          loading: false,
          [params._service]: {
            ...state[params._service],
            loading: false,
            error: null,
            append: { ...state[params._service].append, [params.pid]: data },
          },
        };
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          loading: false,
          error: null,
          list: data,
          schema: schema,
          count,
          append: {},
          done: false,
          pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
        },
      };
    case "clearExcelData": {
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          loading: false,
          excelData: null,
        },
      };
    }
    case "/" + params.id:
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          loading: false,
          error: null,
          info: data,
        },
      };
    case "add":
      toast.success(message);
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          loading: false,
          error: null,
          done: true,
        },
      };
    case "update/" + params.id:
      if (!params["silent"]) toast.success(message);
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          loading: false,
          error: null,
          done: true,
        },
      };
    case "delete/" + params.id:
      if (!params["silent"]) toast.success(message);
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          loading: false,
          error: null,
          done: true,
        },
      };
    case "loading":
      return {
        ...state,
        loading: true,
        [params._service]: {
          ...state[params._service],
          loading: true,
          done: false,
        },
      };
    case "error":
      toast.error(message, { autoClose: !message.includes("!!") });
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          loading: false,
          error: data.message,
          done: false,
        },
      };
    case "timeReport":
      return {
        ...state,
        loading: false,
        [params._service]: {
          ...state[params._service],
          timeReport: data,
          error: null,
        },
      };
    case "bpms_workflow/" + params.id:
      console.log("case");
      return { ...state, loading: false, info: { data: "sd" } };
    default:
      return state;
  }
}
