const initialState = {
  themeName: window.localStorage.getItem("themeName") || "default",
  version: window.localStorage.getItem("version"),
  menu: true,
  header: true,
  bottomSheet: {
    children: null,
    open: null,
  },
  dialog: {
    text: null,
    type: null,
    accept: null,
    open: null,
  },
  device: "mobile",
  themeColors: {
    default: {
      name: "روشن",
      "--primary": "#3D5AFE",
      "--primaryLight": "#536DFE",
      "--primaryText": "#FFFFFF",
      "--primaryDark": "#304FFE",
      "--secondary": "#2196F3",
      "--secondaryText": "#fff",
      "--secondaryDark": "#356dc4",
      "--secondaryLight": "#609bf7",
      "--background": "#f9fbfc",
      "--backgroundText": "#00253A",
      "--surface": "#f2f7fc",
      "--surfaceDark": "#f1f8ff",
      "--surfaceLight": "#f9fcff",
      "--surfaceText": "#333333",
      "--surfaceBorder": "#e9e9e9",
      "--info": "#43c1ff",
      "--infoText": "#000000",
      "--success": "#42b258",
      "--successText": "#fff",
      "--warning": "#ffcc00",
      "--warningText": "#000000",
      "--error": "#D81111",
      "--errorText": "#FFFFFF",
      "--borderColor": "#E4E4E4",
      "--backgroundBorder": "#ECECEC",
      "--white": "#ffffff",
    },
    dark: {
      name: "تیره",
      "--primary": "#37AA9C",
      "--primaryLight": "#48b5a6",
      "--primaryText": "#fff",
      "--primaryDark": "#2c998a",
      "--secondary": "#94F3E4",
      "--secondaryText": "#000000",
      "--secondaryDark": "#60c1b1",
      "--secondaryLight": "#bffff4",
      "--background": "#20292d",
      "--backgroundText": "#EEE",
      "--surface": "#333F44",
      "--surfaceDark": "#2b363a",
      "--surfaceLight": "#38454B",
      "--surfaceText": "#cccccc",
      "--surfaceBorder": "#e9e9e9",
      "--info": "#43c1ff",
      "--infoText": "#000000",
      "--success": "#42b258",
      "--successText": "#fff",
      "--warning": "#f1d416",
      "--warningText": "#000000",
      "--error": "#c4342d",
      "--errorText": "#FFFFFF",
      "--borderColor": "#E4E4E430",
      "--backgroundBorder": "#ECECEC",
      "--white": "#ffffff",
    },
    brown: {
      name: "قهوه‌ای",
      "--primary": "#806854",
      "--primaryLight": "#967e6a",

      "--primaryText": "#fff",
      "--primaryDark": "#3e0c5b",

      "--secondary": "#A8BAA9",

      "--secondaryText": "#000000",
      "--secondaryDark": "#6d5cd1",
      "--secondaryLight": "#b3a6fc",
      "--background": "#fcf7e5",
      "--backgroundText": "#494949",
      "--surface": "#fffde2",
      "--surfaceDark": "#e0dcd2",
      "--surfaceLight": "#ebdec0",
      "--surfaceText": "#000000",
      "--surfaceBorder": "#c4beb4",

      "--info": "#43c1ff",
      "--infoText": "#000000",
      "--success": "#42b258",
      "--successText": "#000000",
      "--warning": "#ffa200",
      "--warningText": "#000000",
      "--error": "#D81111",
      "--errorText": "#FFFFFF",
      "--borderColor": "#c4beb499",

      "--backgroundBorder": "#c4bdb4",
      "--white": "#ffffff",
    },
    purpule: {
      name: "بنفش",
      "--primary": "#561977",
      "--primaryLight": "#7F3AB8",
      "--primaryText": "#fff",
      "--primaryDark": "#3e0c5b",
      "--secondary": "#9D8AFF",
      "--secondaryText": "#000000",
      "--secondaryDark": "#6d5cd1",
      "--secondaryLight": "#b3a6fc",
      "--background": "#f8f7fc",
      "--backgroundText": "#494949",
      "--surface": "#f8f4ff",
      "--surfaceDark": "#e5f9f9",
      "--surfaceLight": "#c7e8fc",
      "--surfaceText": "#000000",
      "--surfaceBorder": "#b4bec4",
      "--info": "#43c1ff",
      "--infoText": "#000000",
      "--success": "#42b258",
      "--successText": "#000000",
      "--warning": "#ffa200",
      "--warningText": "#000000",
      "--error": "#D81111",
      "--errorText": "#FFFFFF",
      "--borderColor": "#b4bec430",
      "--backgroundBorder": "#b4bec4",
      "--white": "#ffffff",
    },
  },
};

export default function config(state = initialState, action) {
  let { type, data } = action;
  switch (type) {
    case "config/setMenu":
      return {
        ...state,
        menu: data,
      };
    case "config/setHeader":
      return {
        ...state,
        header: data,
      };
    case "config/setDialog":
      return {
        ...state,
        dialog: data,
      };
    case "config/setBottomSheet":
      return {
        ...state,
        bottomSheet: data,
      };
    case "config/setTheme":
      return {
        ...state,
        themeName: data,
      };
    case "config/addTheme":
      return {
        ...state,
        themeColors: { ...state.themeColors, [data.key]: { ...data.value } },
      };
    case "config/deleteTheme":
      return {
        ...state,
        themeColors: data,
      };
    case "config/setDevice":
      return {
        ...state,
        device: data,
      };
    default:
      return state;
  }
}
