import proxy from "~/redux/proxy";
import { toast } from "react-toastify";
const status = proxy.status();
const initialState = {
  status,
  loading: false,
  error: null,
  list: [],
  schema: [],
  excelData: [],
  nationalIdLog: null,
};

export default function healthCard(state = initialState, action) {
  let { type, data, schema, count, params } = action;
  switch (type) {
    case "healthCard/getJobs":
      return {
        ...state,
        loading: false,
        error: null,
        jobList: data,
        schema: schema,
        count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "healthCard/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          error: null,
          schema: schema,
          excelData: data,
        };
      return {
        ...state,
        loading: false,
        error: null,
        list: data,
        schema: schema,
        count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "user/clearExcelData": {
      return {
        ...state,
        loading: false,
        excelData: null,
      };
    }
    case "healthCard/updatePrintDate":
      toast.success(data.message);
      return { ...state, loading: false, error: null };
    case "healthCard/setVoid":
      toast.success(data.message);
      return { ...state, loading: false, error: null };
    case "healthCard/revertAutoCancel":
      toast.success(data.message);
      return { ...state, loading: false, error: null };
    case "healthCard/changeJobId":
      toast.success(data.message);
      return { ...state, loading: false, error: null };
    case "healthCard/abate":
      toast.success(data.message);
      return { ...state, loading: false, error: null };
    case "healthCard/voidIncorrectUniversity":
      toast.success(data.message);
      return { ...state, loading: false, error: null };
    case "healthCard/forceApprove":
      toast.success(data.message);
      return { ...state, loading: false, error: null };
    case "healthCard/nationalIdLog":
      return { ...state, nationalIdLog: data, loading: false, error: null };
    case "healthCard/add":
      return { ...state, loading: false, error: null };
    case "healthCard/delete":
      return { ...state, loading: false, error: null };
    case "healthCard/loading":
      return { ...state, loading: true };
    case "healthCard/error":
      toast.error(data.message, { autoClose: !data.message.includes("!!") });
      return { ...state, loading: false, error: data.message };
    default:
      return state;
  }
}
