import proxy from "~/redux/proxy";
import { toast } from "react-toastify";
const status = proxy.status();
const initialState = {
  status,
  loading: false,
  error: null,
  list: [],
  schema: [],
  excelData: [],
  statics: [],
};

export default function inspection(state = initialState, action) {
  let { type, data, schema, count, params, message } = action;
  switch (type) {
    case "bpms/inspection/statistics/network":
      return {
        ...state,
        statics: data,
        loading: false,
        excelData: null,
      };
    case "inspection/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          error: null,
          schema: schema,
          excelData: data,
        };
      return {
        ...state,
        loading: false,
        error: null,
        list: data,
        schema: schema,
        count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "inspection/clearExcelData": {
      return {
        ...state,
        loading: false,
        excelData: null,
      };
    }
    case "inspection/add":
      return { ...state, loading: false, error: null };
    case "inspection/delete":
      return { ...state, loading: false, error: null };
    case "inspection/loading":
    case "bpms/loading":
      return { ...state, loading: true };
    case "inspection/error":
    case "bpms/error":
      toast.error(message || data.message);
      return { ...state, loading: false, error: data.message };
    default:
      return state;
  }
}
