import { toast } from "react-toastify";
const menuList = window.sessionStorage.getItem("menu");
const initialState = {
  loading: false,
  error: null,
  list: menuList
    ? JSON.parse(menuList)
    : [
        {
          id: 1e6,
          pid: null,
          title: "خروج",
          icon: "Logout",
          link: "/logout",
          type: 1,
        },
      ],
  info: null,
  adminList: [],
  homePage: [],
};

export default function menu(state = initialState, action) {
  let { type, data, schema, count, params = {} } = action;
  switch (type) {
    case "menu/homePage":
      return { ...state, loading: false, error: null, homePage: data };
    case "menu/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          error: null,
          schema: schema,
          excelData: data,
        };
      data = data.map((e) => ({
        ...e,
        title: e.description,
        link: e.name,
        icon: e.icon && e.icon.includes("/") ? undefined : e.icon,
      }));

      if (!params.service)
        data.push({
          pid: null,
          id: 1e6,
          type: 1,
          title: "خروج",
          icon: "Logout",
          link: "/logout",
        });
      else
        data.push({
          pid: null,
          id: 1e6,
          type: 1,
          title: "بازگشت",
          icon: "Logout",

          link: "/",
        });
      window.sessionStorage.setItem("menu", JSON.stringify(data));
      return {
        ...state,
        loading: false,
        error: null,
        list: data,
        schema: schema,
        count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "menu/admin/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          error: null,
          schema: schema,
          excelData: data,
        };
      data = data.map((e) => ({
        ...e,
        title: e.description,
        link: e.name,
        icon: e.icon,
      }));
      return {
        ...state,
        loading: false,
        error: null,
        adminList: data,
        schema: schema,
        count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "menu/info":
      return { ...state, loading: false, error: null, info: data };
    case "menu/add":
      return { ...state, loading: false, error: null };
    case "menu/homePage":
      return { ...state, loading: false, error: null, list: data.list };
    case "menu/delete":
      return { ...state, loading: false, error: null };
    case "menu/update":
      return { ...state, loading: false, error: null };
    case "menu/loading":
      return { ...state, loading: true };
    case "menu/error":
      toast.error(data?.message, { autoClose: !data?.message.includes("!!") });

      return { ...state, loading: false, error: data?.message || data };
    default:
      return state;
  }
}
