import proxy from "~/redux/proxy";
import { toast } from "react-toastify";
const status = proxy.status();
const initialState = {
  status,
  loading: false,
  error: null,
  list: [],
  schema: [],
  excelData: [],
  similarList: [],
};

export default function network(state = initialState, action) {
  let { type, data, schema, count, params, message } = action;
  switch (type) {
    case "network/similar":
      return { ...state, loading: false, similarList: data, error: null };
    case "network/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          error: null,
          schema: schema,
          excelData: data,
        };
      data = data.map((e) => ({
        ...e,
        isDraggable: e.level == 4,
        isDropable: e.level == 3,
      }));
      if (params._append)
        return {
          ...state,
          loading: false,
          error: null,
          append: { ...state.append, [params.pid]: data },
          schema: schema,
          count,
          pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
        };
      return {
        ...state,
        loading: false,
        error: null,
        list: data,
        schema: schema,
        count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
        append: {},
      };
    case "user/clearExcelData": {
      return {
        ...state,
        loading: false,
        excelData: null,
      };
    }
    case "network/add":
      return { ...state, loading: false, error: null };
    case "network/transfer":
      toast.success("جابجایی با موفقیت انجام شد");
      return { ...state, loading: false, error: null };
    case "network/delete":
      return { ...state, loading: false, error: null };
    case "network/loading":
      return { ...state, loading: true };
    case "network/error":
      toast.error(message, { autoClose: !message.includes("!!") });
      return { ...state, loading: false, error: message };
    default:
      return state;
  }
}
