import { toast } from "react-toastify";

const initialState = {
  loading: false,
  error: null,
  list: [],
  checklists: {},
  saved: null,
  startable: [],
  taskId: null,
  processList: [],
  sampelingList: [],
  unread: 0,
  inbox: 0,
  important: 0,
};
export default function task(state = initialState, action) {
  let { type, data, schema, count, params, message } = action;

  switch (type) {
    case "bpms/watersupply/startInspection":
      toast.info(message);
      return {
        ...state,
        loading: false,
        error: null,
      };
    case "bpms/process/list":
      return {
        ...state,
        loading: false,
        processList: data,
        error: null,
      };
    case "bpms/periodicSampling":
      return {
        ...state,
        loading: false,
        sampelingList: data,
        error: null,
      };
    case "bpms/samplingStart":
      return {
        ...state,
        loading: false,
        error: null,
      };
    case "bpms/process/startable":
      return {
        ...state,
        loading: false,
        startable: data,
        error: null,
      };
    case "bpms/inboxInfo":
      return {
        ...state,
        loading: false,
        inbox: data.inbox,
        important: data.important,
        unread: data.unread,
        version: data.version,
        error: null,
      };
    case "bpms/process/start":
      return {
        ...state,
        loading: false,
        taskId: data?.id,
        error: null,
      };
    case "bpms/task/checklistInfo":
      return {
        ...state,
        loading: false,
        checklists: { ...state.checklists, [params.checklistId]: data },
        error: null,
        count,
        schema: schema,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "bpms/task/getExcelData":
      return {
        ...state,
        loading: false,
        excelData: data,
      };
    case "bpms/task/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          excelData: data,
        };
      return {
        ...state,
        loading: false,
        list: data,
        error: null,
        count,
        schema: schema,
        saved: null,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "bpms/taskFlow/inactive":
      toast.success("غیر فعال سازی با موفقیت انجام شد");
      return {
        ...state,
        loading: false,
        error: null,
        taskId: null,
      };
    case "bpms/task/info":
      return {
        ...state,
        info: data,
        schema: schema,
        loading: false,
        error: null,
        taskId: null,
        unread: data.unread,
        inbox: data.inbox,
        important: data.important,
      };
    case "bpms/task/tree":
      return {
        ...state,
        tree: data,
        schema: schema,
        loading: false,
        error: null,
        taskId: null,
      };
    case "bpms/task/cancel":
      toast.success("انصراف با موفقیت انجام شد");
      return {
        ...state,
        saved: params.taskId || params.taskIds,
        loading: false,
        error: null,
      };
    case "bpms/task/rollback":
    case "bpms/task/rollback2":
      toast.success("ّبازگشت با موفقیت انجام شد");
      return {
        ...state,
        saved: params.taskId || params.taskIds,
        loading: false,
        error: null,
      };
    case "bpms/task/draft":
    case "bpms/task/archive":
    case "bpms/task/revert":
    case "bpms/task/done":
      toast.success("ثبت با موفقیت انجام شد");
      return {
        ...state,
        saved: params.taskId || params.taskIds,
        loading: false,
        error: null,
      };
    case "bpms/htmlCreator":
      return {
        ...state,
        html: data,
        loading: false,
        error: null,
      };
    case "bpms/loading":
      return { ...state, loading: true };
    case "bpms/error":
      return { ...state, loading: false, error: message };
    default:
      return state;
  }
}
