import proxy from "~/redux/proxy";
import { toast } from "react-toastify";
const status = proxy.status();
const initialState = {
  status,
  loading: false,
  error: null,
  list: [],
  schema: [],
  excelData: [],
  instructions: [],
  instructions_count: 0,
  instructions_schema: [],
  contractLimit: null,
};

export default function unit(state = initialState, action) {
  let { type, data, schema, count, params, message } = action;
  switch (type) {
    case "unit/instructions":
      return {
        ...state,
        loading: false,
        error: null,
        instructions: data,
        instructions_schema: schema,
        instructions_count: count,
        instructions_pageCount: 1,
      };
    case "unit/healthQualification/list":
      return {
        ...state,
        loading: false,
        error: null,
        healthQualification_list: date,
      };
    case "unit/checkContractLimit":
      return {
        ...state,
        contractLimit: data,
        loading: false,
        error: null,
      };
    case "unit/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          error: null,
          schema: schema,
          excelData: data,
        };
      return {
        ...state,
        loading: false,
        error: null,
        list: data,
        schema: schema,
        count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "unit/info":
      return {
        ...state,
        loading: false,
        error: null,
        info: data,
      };
    case "user/clearExcelData": {
      return {
        ...state,
        loading: false,
        excelData: null,
      };
    }
    case "unit/freeAuditorRevoke": {
      toast.success(message);
      return {
        ...state,
        loading: false,
        error: null,
      };
    }
    case "unit/add":
      toast.success(message);
      return { ...state, loading: false, error: null, done: true };
    case "unit/update":
      toast.success(message);
      return { ...state, loading: false, error: null, done: true };
    case "unit/delete":
      toast.success(message);
      return { ...state, loading: false, error: null, done: true };
    case "unit/loading":
      return { ...state, loading: true, done: false };
    case "unit/error":
      toast.error(message, { autoClose: !message.includes("!!") });
      return { ...state, loading: false, error: message, done: false };
    default:
      return state;
  }
}
