import proxy from "~/redux/proxy";
import { toast } from "react-toastify";
import config from "~/config";
const status = proxy.status();
const initialState = {
  status,
  loading: false,
  error: null,
  profileStatus: false,
  profileFields: {},
  info: {},
  list: [],
  schema: [],
  ActiveRoleId: +localStorage.getItem("activeRoleId"),
  userRoles: status?.userRoles || [],
  roleId: null,
  excelData: [],
  captchaRequired: false,
  restrictionEnd: null,
  profile: {},
  afterSchema:
    status?.roleId == 23 || status?.roleId == 209
      ? [
          {
            name: "otlt",
            primary: false,
            type: "button",
            description: "ورود ادمین",

            desc: "ورود ادمین",
            // icon: "key",
            filterable: false,
            action: async (row) => {
              let response = await window.Axios.post("/user/admin/otlt", {
                userId: row.id,
              });
              navigator.clipboard.writeText(
                window.location.origin +
                  `/clients/login?userId=${row.id}&otlt=${response.data.data.otlt}`
              );
              toast.info("لینک ورود کپی شد");
            },
          },
        ]
      : [],
};

export default function user(state = initialState, action) {
  let { type, data, schema, count, params, message } = action;
  switch (type) {
    case "user/switchRole":
      toast.success("نقش با موفقیت تغییر کرد");
    case "user/login":
    case "user/otp/login":

    case "user/otp/register":
    case "user/otp/sameh/login":
    case "user/sso/login":
    case "user/sso/login2":
      return {
        ...state,
        captchaRequired: false,
        restrictionEnd: null,
        loading: false,
        status: data,
        userRoles: data.userRoles,
        roleId: data.roleId,
        userRoleId: data.userRoleId,
        error: null,
        ActiveRoleId:
          state.ActiveRoleId ||
          (data?.userRoles?.length > 1 ? state.ActiveRoleId : data.userRoleId),
      };
    case "user/register":

    case "public/sendOTP":
      return { ...state, loading: false, status: data.profile, error: null };
    case "user/signer":
      return { ...state, loading: false, info: data, error: null };
    case "user/logout":
      localStorage.removeItem("activeRoleId");
      return {
        ...state,
        loading: false,
        status: proxy.status(),
        error: null,
        ActiveRoleId: null,
      };
    case "user/getProfile":
      // localStorage.setItem("userData", JSON.stringify(data));
      return {
        ...state,
        schema,
        loading: false,
        profile: data,
        error: null,
        setDone: false,
      };
    case "user/setActiveRoleId":
      window.localStorage.setItem("activeRoleId", String(data));
      return { ...state, loading: false, ActiveRoleId: data };
    case "user/referAndDeleteUserRole":
      toast.success("تغییرات اعمال شد.");
      return { ...state, loading: false, error: null };
    case "user/setProfile":
      toast.success("تغییرات اعمال شد.");
      return { ...state, loading: false, error: null, setDone: true };
    case "user/getUserRole":
      return { ...state, loading: false, userRoles: data, error: null };
    case "user/copyRoleFunction":
      toast.success("تغییرات اعمال شد.");
      return { ...state, loading: false, error: null };
    case "user/list":
      if (params.excelData)
        return {
          ...state,
          loading: false,
          error: null,
          schema: schema,
          excelData: data,
        };
      return {
        ...state,
        loading: false,
        error: null,
        list: data,
        schema: schema,
        count: count,
        pageCount: +Math.floor((count - 1) / params.pageSize) + 1,
      };
    case "user/clearExcelData": {
      return {
        ...state,
        loading: false,
        excelData: null,
      };
    }
    case "user/add":
      toast.success("با موفقیت ثبت شد");
      return { ...state, loading: false, error: null };
    case "user/update":
      toast.success("تغییرات اعمال شد.");
      return { ...state, loading: false, error: null };
    case "user/info":
      return { ...state, loading: false, error: null, info: data };
    case "user/delete":
      return { ...state, loading: false, error: null };
    case "user/loading":
      return { ...state, loading: true };
    case "user/error":
      if (data?.message || message) toast.error(data?.message || message);

      return {
        ...state,
        loading: false,
        captchaRequired: data?.captchaRequired,
        restrictionEnd: data?.restrictionEnd,
        error: data?.message || data,
      };
    default:
      return state;
  }
}
